@@ -4,6 +4,7 @@ import logging, sys
 import baker
 
 from .config import Config
+from .work_queue import work_queue
 
 logger = logging.getLogger('yoink.app')
 
@@ -13,9 +14,15 @@ logging.basicConfig(level=logging.DEBUG,
 
 @baker.command(default=True)
 def update(config_file='~/.yoink.conf', preview=False):
+    '''Update all feeds, downloading new files as available, and
+    updating the config file's timestamps appropriately.
+    '''
     with Config(config_file, preview) as config:
-        for feed in config.feeds():
-            feed.update()
+        # Queue up the feeds
+        [work_queue.add_job(feed.update) for feed in config.feeds.values()]
+
+        # Wait for everything to finish
+        work_queue.wait()
 
 def main():
     baker.run()
